@@ -4,7 +4,7 @@
 from dgis.binder import bind_api
 
 
-__version__ = '0.8.6'
+__version__ = '0.8.9'
 
 
 class API(object):
@@ -92,6 +92,15 @@ class API(object):
         http://api.2gis.ru/doc/firms/searches/searchinrubric/
         """
 
+        point = kwargs.pop('point', False)
+        if point:
+            kwargs['point'] = '%s,%s' % point
+
+        bound = kwargs.pop('bound', False)
+        if bound:
+            kwargs['bound[point1]'] = bound[0]
+            kwargs['bound[point2]'] = bound[1]
+
         filters = kwargs.pop('filters', False)
         if filters:
             for k, v in filters.items():
@@ -101,7 +110,7 @@ class API(object):
 
     _search_in_rubric = bind_api(
         path='/searchinrubric',
-        allowed_param=['what', 'where', 'page', 'pagesize', 'sort', 'filters'],
+        allowed_param=['what', 'where', 'point', 'radius', 'bound', 'page', 'pagesize', 'sort', 'filters'],
     )
 
     """Firm filials
@@ -110,7 +119,7 @@ class API(object):
     """
     firms_by_filial_id = bind_api(
         path='/firmsByFilialId',
-        allowed_param=['firmid', ],
+        allowed_param=['firmid', 'page' 'pagesize'],
     )
 
     """Adverts search
